@@ -1,5 +1,7 @@
+#' @title
 #' Extract wrapped function.
 #'
+#' @description
 #' The \pkg{smoof} package offers means to let a function log its evaluations or
 #' even store to points and function values it has been evaluated on. This is done
 #' by wrapping the function with other functions. This helper function extract
@@ -23,6 +25,7 @@ getWrappedFunction = function(fn, deepest = FALSE) {
 
 #' @export
 getWrappedFunction.smoof_wrapped_function = function(fn, deepest = FALSE) {
+  assertFlag(deepest)
   wrapped.fn = environment(fn)$fn
   if (deepest) {
     return(getWrappedFunction(wrapped.fn, deepest))
