@@ -21,7 +21,7 @@
 #' @return [\code{smoof_multi_objective_function}]
 #' @export
 makeZDT4Function = function(dimensions) {
-  assertNumber(dimensions, lower = 2L)
+  assertInt(dimensions, lower = 2L)
   force(dimensions)
 
   # define the two-objective ZDT1 function
