@@ -11,7 +11,9 @@
 makeComplexFunction = function() {
   makeSingleObjectiveFunction(
     name = "Complex Function",
+    id = paste0("complex_2d"),
     fn = function(x) {
+      assertNumeric(x, len = 2L, any.missing = FALSE, all.missing = FALSE)
       (x[1]^3 - 3 * x[1] * x[2]^2 - 1)^2 + (3 * x[2] * x[1]^2 - x[2]^3)^2
     },
     par.set = makeNumericParamSet(
@@ -28,6 +30,6 @@ makeComplexFunction = function() {
 }
 
 class(makeComplexFunction) = c("function", "smoof_generator")
-attr(makeComplexFunction, "name") = c("Complex Function")
+attr(makeComplexFunction, "name") = c("Complex")
 attr(makeComplexFunction, "type") = c("single-objective")
-attr(makeComplexFunction, "tags") = c("continuous", "differentiable", "non-separable", "non-scalable", "multimodal")
+attr(makeComplexFunction, "tags") = c("single-objective", "continuous", "differentiable", "non-separable", "non-scalable", "multimodal")
